import sys; sys.dont_write_bytecode=True
import json
import requests as req


endpoint = lambda TICKER: f'https://project-finance-backend.onrender.com/info/{TICKER}'


def get(TICKER='MSFT'): 
    return json.loads(req.get(endpoint(TICKER)).content)


sample_req = 'https://project-finance-backend.onrender.com/info/MSFT'

sample_res = {
  "address1": "One Microsoft Way",
  "city": "Redmond",
  "state": "WA",
  "zip": "98052-6399",
  "country": "United States",
  "phone": "425 882 8080",
  "website": "https://www.microsoft.com",
  "industry": "Software - Infrastructure",
  "industryKey": "software-infrastructure",
  "industryDisp": "Software - Infrastructure",
  "sector": "Technology",
  "sectorKey": "technology",
  "sectorDisp": "Technology",
  "longBusinessSummary": "Microsoft Corporation develops and supports software, services, devices and solutions worldwide. The Productivity and Business Processes segment offers office, exchange, SharePoint, Microsoft Teams, office 365 Security and Compliance, Microsoft viva, and Microsoft 365 copilot; and office consumer services, such as Microsoft 365 consumer subscriptions, Office licensed on-premises, and other office services. This segment also provides LinkedIn; and dynamics business solutions, including Dynamics 365, a set of intelligent, cloud-based applications across ERP, CRM, power apps, and power automate; and on-premises ERP and CRM applications. The Intelligent Cloud segment offers server products and cloud services, such as azure and other cloud services; SQL and windows server, visual studio, system center, and related client access licenses, as well as nuance and GitHub; and enterprise services including enterprise support services, industry solutions, and nuance professional services. The More Personal Computing segment offers Windows, including windows OEM licensing and other non-volume licensing of the Windows operating system; Windows commercial comprising volume licensing of the Windows operating system, windows cloud services, and other Windows commercial offerings; patent licensing; and windows Internet of Things; and devices, such as surface, HoloLens, and PC accessories. Additionally, this segment provides gaming, which includes Xbox hardware and content, and first- and third-party content; Xbox game pass and other subscriptions, cloud gaming, advertising, third-party disc royalties, and other cloud services; and search and news advertising, which includes Bing, Microsoft News and Edge, and third-party affiliates. The company sells its products through OEMs, distributors, and resellers; and directly through digital marketplaces, online, and retail stores. The company was founded in 1975 and is headquartered in Redmond, Washington.",
  "fullTimeEmployees": 228000,
  "companyOfficers": [
    {
      "maxAge": 1,
      "name": "Mr. Satya  Nadella",
      "age": 57,
      "title": "Chairman & CEO",
      "yearBorn": 1967,
      "fiscalYear": 2024,
      "totalPay": 7869791,
      "exercisedValue": 0,
      "unexercisedValue": 0
    },
    {
      "maxAge": 1,
      "name": "Mr. Bradford L. Smith LCA",
      "age": 65,
      "title": "President & Vice Chairman",
      "yearBorn": 1959,
      "fiscalYear": 2024,
      "totalPay": 4755618,
      "exercisedValue": 0,
      "unexercisedValue": 0
    },
    {
      "maxAge": 1,
      "name": "Ms. Amy E. Hood",
      "age": 52,
      "title": "Executive VP & CFO",
      "yearBorn": 1972,
      "fiscalYear": 2024,
      "totalPay": 4704250,
      "exercisedValue": 0,
      "unexercisedValue": 0
    },
    {
      "maxAge": 1,
      "name": "Mr. Judson B. Althoff",
      "age": 50,
      "title": "Executive VP & Chief Commercial Officer",
      "yearBorn": 1974,
      "fiscalYear": 2024,
      "totalPay": 4534974,
      "exercisedValue": 0,
      "unexercisedValue": 0
    },
    {
      "maxAge": 1,
      "name": "Mr. Christopher David Young",
      "age": 52,
      "title": "Executive Officer",
      "yearBorn": 1972,
      "fiscalYear": 2024,
      "totalPay": 2993772,
      "exercisedValue": 0,
      "unexercisedValue": 0
    },
    {
      "maxAge": 1,
      "name": "Ms. Carolina  Dybeck Happe",
      "age": 52,
      "title": "Executive VP & COO",
      "yearBorn": 1972,
      "fiscalYear": 2024,
      "exercisedValue": 0,
      "unexercisedValue": 0
    },
    {
      "maxAge": 1,
      "name": "Ms. Alice L. Jolla",
      "age": 58,
      "title": "Corporate VP & Chief Accounting Officer",
      "yearBorn": 1966,
      "fiscalYear": 2024,
      "exercisedValue": 0,
      "unexercisedValue": 0
    },
    {
      "maxAge": 1,
      "name": "Mr. James Kevin Scott",
      "age": 52,
      "title": "Executive VP of AI & CTO",
      "yearBorn": 1972,
      "fiscalYear": 2024,
      "exercisedValue": 0,
      "unexercisedValue": 0
    },
    {
      "maxAge": 1,
      "name": "Mr. Brett  Iversen",
      "title": "Vice President of Investor Relations",
      "fiscalYear": 2024,
      "exercisedValue": 0,
      "unexercisedValue": 0
    },
    {
      "maxAge": 1,
      "name": "Mr. Hossein  Nowbar",
      "title": "Chief Legal Officer",
      "fiscalYear": 2024,
      "exercisedValue": 0,
      "unexercisedValue": 0
    }
  ],
  "auditRisk": 9,
  "boardRisk": 5,
  "compensationRisk": 3,
  "shareHolderRightsRisk": 2,
  "overallRisk": 3,
  "governanceEpochDate": 1740787200,
  "compensationAsOfEpochDate": 1735603200,
  "irWebsite": "http://www.microsoft.com/investor/default.aspx",
  "executiveTeam": [],
  "maxAge": 86400,
  "priceHint": 2,
  "previousClose": 378.8,
  "open": 372.535,
  "dayLow": 367.24,
  "dayHigh": 373.04,
  "regularMarketPreviousClose": 378.8,
  "regularMarketOpen": 372.535,
  "regularMarketDayLow": 367.24,
  "regularMarketDayHigh": 373.04,
  "dividendRate": 3.32,
  "dividendYield": 0.88,
  "exDividendDate": 1747267200,
  "payoutRatio": 0.2482,
  "fiveYearAvgDividendYield": 0.85,
  "beta": 0.914,
  "trailingPE": 30,
  "forwardPE": 24.923079,
  "volume": 15731794,
  "regularMarketVolume": 15731965,
  "averageVolume": 22908383,
  "averageVolume10days": 20756090,
  "averageDailyVolume10Day": 20756090,
  "bid": 371.01,
  "ask": 375.97,
  "bidSize": 3,
  "askSize": 3,
  "marketCap": 2769901060096,
  "fiftyTwoWeekLow": 367.24,
  "fiftyTwoWeekHigh": 468.35,
  "priceToSalesTrailing12Months": 10.580137,
  "fiftyDayAverage": 405.844,
  "twoHundredDayAverage": 422.5207,
  "trailingAnnualDividendRate": 3.16,
  "trailingAnnualDividendYield": 0.008342134,
  "currency": "USD",
  "tradeable": False,
  "enterpriseValue": 2847346524160,
  "profitMargins": 0.35428002,
  "floatShares": 7423574660,
  "sharesOutstanding": 7433979904,
  "sharesShort": 64256703,
  "sharesShortPriorMonth": 53633341,
  "sharesShortPreviousMonthDate": 1739491200,
  "dateShortInterest": 1741910400,
  "sharesPercentSharesOut": 0.0086,
  "heldPercentInsiders": 0.00063,
  "heldPercentInstitutions": 0.74452,
  "shortRatio": 2.58,
  "shortPercentOfFloat": 0.0086,
  "impliedSharesOutstanding": 7433979904,
  "bookValue": 40.712,
  "priceToBook": 9.152093,
  "lastFiscalYearEnd": 1719705600,
  "nextFiscalYearEnd": 1751241600,
  "mostRecentQuarter": 1735603200,
  "earningsQuarterlyGrowth": 0.102,
  "netIncomeToCommon": 92749996032,
  "trailingEps": 12.42,
  "forwardEps": 14.95,
  "lastSplitFactor": "2:1",
  "lastSplitDate": 1045526400,
  "enterpriseToRevenue": 10.876,
  "enterpriseToEbitda": 20.046,
  "52WeekChange": -0.107803166,
  "SandP52WeekChange": 0.06429911,
  "lastDividendValue": 0.83,
  "lastDividendDate": 1740009600,
  "quoteType": "EQUITY",
  "currentPrice": 372.6,
  "targetHighPrice": 650,
  "targetLowPrice": 415,
  "targetMeanPrice": 503.86472,
  "targetMedianPrice": 500,
  "recommendationMean": 1.41379,
  "recommendationKey": "strong_buy",
  "numberOfAnalystOpinions": 51,
  "totalCash": 71554998272,
  "totalCashPerShare": 9.625,
  "ebitda": 142041006080,
  "totalDebt": 102909001728,
  "quickRatio": 1.204,
  "currentRatio": 1.351,
  "totalRevenue": 261802000384,
  "debtToEquity": 33.998,
  "revenuePerShare": 35.224,
  "returnOnAssets": 0.14649001,
  "returnOnEquity": 0.34291,
  "grossProfits": 181714993152,
  "freeCashflow": 51958124544,
  "operatingCashflow": 125582999552,
  "earningsGrowth": 0.102,
  "revenueGrowth": 0.123,
  "grossMargins": 0.69408995,
  "ebitdaMargins": 0.54255,
  "operatingMargins": 0.45458,
  "financialCurrency": "USD",
  "symbol": "MSFT",
  "language": "en-US",
  "region": "US",
  "typeDisp": "Equity",
  "quoteSourceName": "Nasdaq Real Time Price",
  "triggerable": True,
  "customPriceAlertConfidence": "HIGH",
  "hasPrePostMarketData": True,
  "firstTradeDateMilliseconds": 511108200000,
  "regularMarketChange": -6.1999817,
  "regularMarketDayRange": "367.24 - 373.04",
  "fullExchangeName": "NasdaqGS",
  "averageDailyVolume3Month": 22908383,
  "fiftyTwoWeekLowChange": 5.360016,
  "fiftyTwoWeekLowChangePercent": 0.014595403,
  "fiftyTwoWeekRange": "367.24 - 468.35",
  "fiftyTwoWeekHighChange": -95.75,
  "fiftyTwoWeekHighChangePercent": -0.20444112,
  "fiftyTwoWeekChangePercent": -10.780316,
  "dividendDate": 1749686400,
  "earningsTimestamp": 1738184400,
  "earningsTimestampStart": 1745438400,
  "earningsTimestampEnd": 1745870400,
  "earningsCallTimestampStart": 1738189800,
  "earningsCallTimestampEnd": 1738189800,
  "isEarningsDateEstimate": True,
  "epsTrailingTwelveMonths": 12.42,
  "epsForward": 14.95,
  "epsCurrentYear": 13.18361,
  "priceEpsCurrentYear": 28.262365,
  "fiftyDayAverageChange": -33.243988,
  "fiftyDayAverageChangePercent": -0.08191322,
  "twoHundredDayAverageChange": -49.920685,
  "twoHundredDayAverageChangePercent": -0.11814968,
  "sourceInterval": 15,
  "exchangeDataDelayedBy": 0,
  "averageAnalystRating": "1.4 - Strong Buy",
  "cryptoTradeable": False,
  "shortName": "Microsoft Corporation",
  "longName": "Microsoft Corporation",
  "marketState": "REGULAR",
  "regularMarketChangePercent": -1.6367428,
  "regularMarketPrice": 372.6,
  "corporateActions": [],
  "regularMarketTime": 1743446519,
  "exchange": "NMS",
  "messageBoardId": "finmb_21835",
  "exchangeTimezoneName": "America/New_York",
  "exchangeTimezoneShortName": "EDT",
  "gmtOffSetMilliseconds": -14400000,
  "market": "us_market",
  "esgPopulated": False,
  "displayName": "Microsoft",
  "trailingPegRatio": 1.732
}


import sys; sys.dont_write_bytecode=True
import pandas as pd


endpoint = lambda pages: f'https://project-finance-backend.onrender.com/financial-list?pages={pages}'


def get(pages=10):
    return pd.read_json(endpoint(pages))


sample_req = 'https://project-finance-backend.onrender.com/financial-list?pages=1'

sample_res = [
  {
    "Country": "USA",
    "Ticker": "AAPL",
    "Name": "Apple",
    "Slug": "apple"
  },
  {
    "Country": "USA",
    "Ticker": "MSFT",
    "Name": "Microsoft",
    "Slug": "microsoft"
  },
  {
    "Country": "USA",
    "Ticker": "NVDA",
    "Name": "NVIDIA",
    "Slug": "nvidia"
  },
  {
    "Country": "USA",
    "Ticker": "AMZN",
    "Name": "Amazon",
    "Slug": "amazon"
  },
  {
    "Country": "USA",
    "Ticker": "GOOG",
    "Name": "Alphabet (Google)",
    "Slug": "alphabet-google"
  },
  {
    "Country": "S. Arabia",
    "Ticker": "2222.SR",
    "Name": "Saudi Aramco",
    "Slug": "saudi-aramco"
  },
  {
    "Country": "USA",
    "Ticker": "META",
    "Name": "Meta Platforms (Facebook)",
    "Slug": "meta-platforms"
  },
  {
    "Country": "USA",
    "Ticker": "BRK-B",
    "Name": "Berkshire Hathaway",
    "Slug": "berkshire-hathaway"
  },
  {
    "Country": "Taiwan",
    "Ticker": "TSM",
    "Name": "TSMC",
    "Slug": "tsmc"
  },
  {
    "Country": "USA",
    "Ticker": "TSLA",
    "Name": "Tesla",
    "Slug": "tesla"
  },
  {
    "Country": "USA",
    "Ticker": "AVGO",
    "Name": "Broadcom",
    "Slug": "broadcom"
  },
  {
    "Country": "USA",
    "Ticker": "LLY",
    "Name": "Eli Lilly",
    "Slug": "eli-lilly"
  },
  {
    "Country": "USA",
    "Ticker": "WMT",
    "Name": "Walmart",
    "Slug": "walmart"
  },
  {
    "Country": "USA",
    "Ticker": "JPM",
    "Name": "JPMorgan Chase",
    "Slug": "jp-morgan-chase"
  },
  {
    "Country": "USA",
    "Ticker": "V",
    "Name": "Visa",
    "Slug": "visa"
  },
  {
    "Country": "China",
    "Ticker": "TCEHY",
    "Name": "Tencent",
    "Slug": "tencent"
  },
  {
    "Country": "USA",
    "Ticker": "XOM",
    "Name": "Exxon Mobil",
    "Slug": "exxon-mobil"
  },
  {
    "Country": "USA",
    "Ticker": "MA",
    "Name": "Mastercard",
    "Slug": "mastercard"
  },
  {
    "Country": "USA",
    "Ticker": "UNH",
    "Name": "UnitedHealth",
    "Slug": "united-health"
  },
  {
    "Country": "USA",
    "Ticker": "COST",
    "Name": "Costco",
    "Slug": "costco"
  },
  {
    "Country": "USA",
    "Ticker": "JNJ",
    "Name": "Johnson & Johnson",
    "Slug": "johnson-and-johnson"
  },
  {
    "Country": "USA",
    "Ticker": "PG",
    "Name": "Procter & Gamble",
    "Slug": "procter-and-gamble"
  },
  {
    "Country": "USA",
    "Ticker": "NFLX",
    "Name": "Netflix",
    "Slug": "netflix"
  },
  {
    "Country": "USA",
    "Ticker": "ORCL",
    "Name": "Oracle",
    "Slug": "oracle"
  },
  {
    "Country": "USA",
    "Ticker": "ABBV",
    "Name": "AbbVie",
    "Slug": "abbvie"
  },
  {
    "Country": "USA",
    "Ticker": "HD",
    "Name": "Home Depot",
    "Slug": "home-depot"
  },
  {
    "Country": "China",
    "Ticker": "BABA",
    "Name": "Alibaba",
    "Slug": "alibaba"
  },
  {
    "Country": "USA",
    "Ticker": "BAC",
    "Name": "Bank of America",
    "Slug": "bank-of-america"
  },
  {
    "Country": "Germany",
    "Ticker": "SAP",
    "Name": "SAP",
    "Slug": "sap"
  },
  {
    "Country": "France",
    "Ticker": "MC.PA",
    "Name": "LVMH",
    "Slug": "lvmh"
  },
  {
    "Country": "USA",
    "Ticker": "KO",
    "Name": "Coca-Cola",
    "Slug": "coca-cola"
  },
  {
    "Country": "Denmark",
    "Ticker": "NVO",
    "Name": "Novo Nordisk",
    "Slug": "novo-nordisk"
  },
  {
    "Country": "USA",
    "Ticker": "TMUS",
    "Name": "T-Mobile US",
    "Slug": "t-mobile-us"
  },
  {
    "Country": "China",
    "Ticker": "1398.HK",
    "Name": "ICBC",
    "Slug": "icbc"
  },
  {
    "Country": "USA",
    "Ticker": "CVX",
    "Name": "Chevron",
    "Slug": "chevron"
  },
  {
    "Country": "France",
    "Ticker": "RMS.PA",
    "Name": "Hermès",
    "Slug": "hermes-international"
  },
  {
    "Country": "China",
    "Ticker": "600519.SS",
    "Name": "Kweichow Moutai",
    "Slug": "kweichow-moutai"
  },
  {
    "Country": "Netherlands",
    "Ticker": "ASML",
    "Name": "ASML",
    "Slug": "asml"
  },
  {
    "Country": "Switzerland",
    "Ticker": "ROG.SW",
    "Name": "Roche",
    "Slug": "roche"
  },
  {
    "Country": "Switzerland",
    "Ticker": "NESN.SW",
    "Name": "Nestlé",
    "Slug": "nestle"
  },
  {
    "Country": "S. Korea",
    "Ticker": "005930.KS",
    "Name": "Samsung",
    "Slug": "samsung"
  },
  {
    "Country": "USA",
    "Ticker": "CRM",
    "Name": "Salesforce",
    "Slug": "salesforce"
  },
  {
    "Country": "China",
    "Ticker": "601288.SS",
    "Name": "Agricultural Bank of China",
    "Slug": "agricultural-bank-of-china"
  },
  {
    "Country": "USA",
    "Ticker": "PM",
    "Name": "Philip Morris International",
    "Slug": "philip-morris"
  },
  {
    "Country": "USA",
    "Ticker": "CSCO",
    "Name": "Cisco",
    "Slug": "cisco"
  },
  {
    "Country": "China",
    "Ticker": "601939.SS",
    "Name": "China Construction Bank",
    "Slug": "china-construction-bank"
  },
  {
    "Country": "UAE",
    "Ticker": "IHC.AE",
    "Name": "International Holding Company",
    "Slug": "international-holding-company"
  },
  {
    "Country": "China",
    "Ticker": "0941.HK",
    "Name": "China Mobile",
    "Slug": "china-mobile"
  },
  {
    "Country": "USA",
    "Ticker": "WFC",
    "Name": "Wells Fargo",
    "Slug": "wells-fargo"
  },
  {
    "Country": "Japan",
    "Ticker": "TM",
    "Name": "Toyota",
    "Slug": "toyota"
  },
  {
    "Country": "USA",
    "Ticker": "ABT",
    "Name": "Abbott Laboratories",
    "Slug": "abbott-laboratories"
  },
  {
    "Country": "USA",
    "Ticker": "IBM",
    "Name": "IBM",
    "Slug": "ibm"
  },
  {
    "Country": "UK",
    "Ticker": "AZN",
    "Name": "AstraZeneca",
    "Slug": "astrazeneca"
  },
  {
    "Country": "USA",
    "Ticker": "MRK",
    "Name": "Merck",
    "Slug": "merck"
  },
  {
    "Country": "USA",
    "Ticker": "MCD",
    "Name": "McDonald",
    "Slug": "mcdonald"
  },
  {
    "Country": "UK",
    "Ticker": "LIN",
    "Name": "Linde",
    "Slug": "linde"
  },
  {
    "Country": "Switzerland",
    "Ticker": "NVS",
    "Name": "Novartis",
    "Slug": "novartis"
  },
  {
    "Country": "UK",
    "Ticker": "SHEL",
    "Name": "Shell",
    "Slug": "shell"
  },
  {
    "Country": "China",
    "Ticker": "601988.SS",
    "Name": "Bank of China",
    "Slug": "bank-of-china"
  },
  {
    "Country": "USA",
    "Ticker": "GE",
    "Name": "General Electric",
    "Slug": "general-electric"
  },
  {
    "Country": "USA",
    "Ticker": "PEP",
    "Name": "Pepsico",
    "Slug": "pepsico"
  },
  {
    "Country": "USA",
    "Ticker": "T",
    "Name": "AT&T",
    "Slug": "att"
  },
  {
    "Country": "UK",
    "Ticker": "HSBC",
    "Name": "HSBC",
    "Slug": "hsbc"
  },
  {
    "Country": "India",
    "Ticker": "RELIANCE.NS",
    "Name": "Reliance Industries",
    "Slug": "reliance-industries"
  },
  {
    "Country": "Netherlands",
    "Ticker": "PRX.AS",
    "Name": "Prosus",
    "Slug": "prosus"
  },
  {
    "Country": "France",
    "Ticker": "OR.PA",
    "Name": "L'Oréal",
    "Slug": "l-oreal"
  },
  {
    "Country": "USA",
    "Ticker": "PLTR",
    "Name": "Palantir",
    "Slug": "palantir"
  },
  {
    "Country": "Ireland",
    "Ticker": "ACN",
    "Name": "Accenture",
    "Slug": "accenture"
  },
  {
    "Country": "USA",
    "Ticker": "VZ",
    "Name": "Verizon",
    "Slug": "verizon"
  },
  {
    "Country": "China",
    "Ticker": "0857.HK",
    "Name": "PetroChina",
    "Slug": "petro-china"
  },
  {
    "Country": "USA",
    "Ticker": "AXP",
    "Name": "American Express",
    "Slug": "american-express"
  },
  {
    "Country": "USA",
    "Ticker": "MS",
    "Name": "Morgan Stanley",
    "Slug": "morgan-stanley"
  },
  {
    "Country": "USA",
    "Ticker": "TMO",
    "Name": "Thermo Fisher Scientific",
    "Slug": "thermo-fisher-scientific"
  },
  {
    "Country": "Germany",
    "Ticker": "DTE.DE",
    "Name": "Deutsche Telekom",
    "Slug": "deutsche-telekom"
  },
  {
    "Country": "Germany",
    "Ticker": "SIE.DE",
    "Name": "Siemens",
    "Slug": "siemens"
  },
  {
    "Country": "USA",
    "Ticker": "DIS",
    "Name": "Walt Disney",
    "Slug": "walt-disney"
  },
  {
    "Country": "USA",
    "Ticker": "ISRG",
    "Name": "Intuitive Surgical",
    "Slug": "intuitive-surgical"
  },
  {
    "Country": "USA",
    "Ticker": "RTX",
    "Name": "RTX",
    "Slug": "raytheon-technologies"
  },
  {
    "Country": "USA",
    "Ticker": "INTU",
    "Name": "Intuit",
    "Slug": "intuit"
  },
  {
    "Country": "USA",
    "Ticker": "BX",
    "Name": "Blackstone Group",
    "Slug": "blackstone-group"
  },
  {
    "Country": "India",
    "Ticker": "HDB",
    "Name": "HDFC Bank",
    "Slug": "hdfc-bank"
  },
  {
    "Country": "USA",
    "Ticker": "QCOM",
    "Name": "QUALCOMM",
    "Slug": "qualcomm"
  },
  {
    "Country": "USA",
    "Ticker": "GS",
    "Name": "Goldman Sachs",
    "Slug": "goldman-sachs"
  },
  {
    "Country": "Mexico",
    "Ticker": "FMX",
    "Name": "Fomento Económico Mexicano",
    "Slug": "fomento-economico-mexicano"
  },
  {
    "Country": "USA",
    "Ticker": "AMGN",
    "Name": "Amgen",
    "Slug": "amgen"
  },
  {
    "Country": "USA",
    "Ticker": "PGR",
    "Name": "Progressive",
    "Slug": "progressive"
  },
  {
    "Country": "USA",
    "Ticker": "AMD",
    "Name": "AMD",
    "Slug": "amd"
  },
  {
    "Country": "China",
    "Ticker": "PDD",
    "Name": "PDD Holdings (Pinduoduo)",
    "Slug": "pinduoduo"
  },
  {
    "Country": "USA",
    "Ticker": "NOW",
    "Name": "ServiceNow",
    "Slug": "servicenow"
  },
  {
    "Country": "USA",
    "Ticker": "ADBE",
    "Name": "Adobe",
    "Slug": "adobe"
  },
  {
    "Country": "USA",
    "Ticker": "TXN",
    "Name": "Texas Instruments",
    "Slug": "texas-instruments"
  },
  {
    "Country": "China",
    "Ticker": "XIACF",
    "Name": "Xiaomi",
    "Slug": "xiaomi"
  },
  {
    "Country": "China",
    "Ticker": "002594.SZ",
    "Name": "BYD",
    "Slug": "byd"
  },
  {
    "Country": "Canada",
    "Ticker": "RY",
    "Name": "Royal Bank Of Canada",
    "Slug": "royal-bank-of-canada"
  },
  {
    "Country": "Australia",
    "Ticker": "CBA.AX",
    "Name": "Commonwealth Bank",
    "Slug": "commonwealth-bank"
  },
  {
    "Country": "USA",
    "Ticker": "CAT",
    "Name": "Caterpillar",
    "Slug": "caterpillar"
  },
  {
    "Country": "Japan",
    "Ticker": "MUFG",
    "Name": "Mitsubishi UFJ Financial",
    "Slug": "mitsubishi-ufj-financial"
  },
  {
    "Country": "Spain",
    "Ticker": "IDEXY",
    "Name": "Inditex",
    "Slug": "inditex"
  },
  {
    "Country": "USA",
    "Ticker": "SPGI",
    "Name": "S&P Global",
    "Slug": "sp-global"
  },
  {
    "Country": "Japan",
    "Ticker": "SONY",
    "Name": "Sony",
    "Slug": "sony"
  }
]